@@ -39,7 +39,33 @@ pub struct MySqlService {
     service: SystemdService,
 }
 
-impl AptPackage<"mariadb-server"> {
+pub struct MariaDb {
+    service: MySqlService,
+    node: GraphNodeReference,
+}
+
+impl AptPackage for MariaDb {
+    const NAME: &'static str = "mariadb-server";
+
+    fn create(node: GraphNodeReference) -> Self {
+        MariaDb {
+            service: MySqlService {
+                service: SystemdService::from_name_unchecked(
+                    "mariadb",
+                    node,
+                    vec![node],
+                ),
+            },
+            node,
+        }
+    }
+
+    fn graph_node(&self) -> GraphNodeReference {
+        self.node
+    }
+}
+
+impl MariaDb {
     pub fn binary(&self) -> Path<FromPackage> {
         Path {
             base: PathBuf::from("/usr/sbin/mariadb"),
@@ -49,10 +75,8 @@ impl AptPackage<"mariadb-server"> {
         }
     }
 
-    pub fn default_service(&self) -> MySqlService {
-        MySqlService {
-            service: SystemdService::from_name_unchecked("mariadb", self.graph_node(), vec![self.graph_node()]),
-        }
+    pub fn default_service(&mut self) -> &mut MySqlService {
+        &mut self.service
     }
 
     pub fn mysql_user(&self) -> User {
